@@ -73,7 +73,7 @@ class config():
 
     # Output settings
 
-    predicts = 7  # Number of predicted values - 7 by default.
+    predicts = 1  # Number of predicted values - 7 by default.
 
     return_type = 'best'  # 'best', 'all_dataframe', 'detailed_dictionary' or 'models_error_criterion'.
     # 'best' return array of predictions, 'all_dataframe' return results and models names in columns. 'detailed_dictionary' is used for GUI
@@ -380,7 +380,7 @@ class config():
 
     @classmethod
     def freeze(cls):
-        return {key: value for key, value in cls.__dict__.items() if not key.startswith('__') and not callable(key)}
+        return {key: value for key, value in cls.__dict__.items() if not key.startswith('__') and not callable(value) and not (hasattr(value, '__func__') and callable(value.__func__))}
 
 
     @classmethod
