@@ -44,7 +44,7 @@ def load_data(config):
                                                     data_limit=config.max_imported_length)
 
         except Exception:
-            raise RuntimeError(colorize(f"ERROR - Data load from SQL server failed - "
+            raise RuntimeError(colorize("ERROR - Data load from SQL server failed - "
                                         "Setup server, database and predicted column name in config"))
 
     elif config.data_source == 'test':
